@@ -1,8 +1,8 @@
 from django.conf import settings
+from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 from debug_toolbar.panels import DebugPanel
 
-
 try:
     from haystack.backends import queries
     haystack_version = 1
@@ -37,7 +37,7 @@ class HaystackDebugPanel(DebugPanel):
     def title(self):
         return self.nav_title()
 
-    def process_response(self, request, response):
+    def get_context(self):
         query_list = []
 
         if haystack_version == 1:
@@ -46,7 +46,19 @@ class HaystackDebugPanel(DebugPanel):
             query_list = [q for conn in connections.all() for q in conn.queries]
             query_list.sort(key=lambda q: q['start'])
 
-        self.record_stats({
+        return {
             'queries': query_list,
             'debug': getattr(settings, 'DEBUG', False),
-        })
+        }
+
+    def process_response(self, request, response):
+        if hasattr(self, 'record_stats'):
+            self.record_stats(self.get_context())
+
+    def content(self):
+        if hasattr(self, 'record_stats'):
+            return super(HaystackDebugPanel, self).content()
+        else:
+            context = self.context.copy()
+            context.update(self.get_context())
+            return render_to_string(self.template, context)
